<?php

// $Id: views.inc,v 1.13 2007/12/04 17:20:01 drewish Exp $

/**
 * Implementation of hook_views_tables().
 */
function station_archive_views_tables() {
  $tables['station_archive_item'] = array(
    'name' => 'station_archive_item',
    'join' => array(
      'left' => array(
        'table' => 'node',
        'field' => 'nid'
      ),
      'right' => array(
        'field' => 'audio_nid'
      )
    ),
    'fields' => array(
      'aired' => array(
        'name' => t('Station Archive: Air date'),
        'sortable' => TRUE,
        'handler' => views_handler_field_dates(),
        'option' => 'string',
        'help' => t('Date the audio was aired.'),
      ),
      'imported' => array(
        'name' => t('Station Archive: Import date'),
        'sortable' => TRUE,
        'handler' => views_handler_field_dates(),
        'option' => 'string',
        'help' => t('Date the audio was imported into the station archive.'),
      ),
    ),
    'filters' => array(
      'permanent' => array(
        'name' => t('Station Archive: Is in permanent archive'),
        'operator' => array('=' => 'Equals'),
        'list' => 'views_handler_operator_yesno',
        'list-type' => 'select',
        'help' => t('Filter whether the node is part of the permanent archive.'),
      ),
    ),
  );
  $tables['station_archive_program'] = array(
    'name' => 'station_archive_program',
    'join' => array(
      'left' => array(
        'table' => 'station_archive_item',
        'field' => 'program_nid'
      ),
      'right' => array(
        'field' => 'program_nid'
      )
    ),
    'fields' => array(
      'title' => array(
        'name' => t('Station Archive: Program title'),
        'sortable' => TRUE,
        'handler' => 'station_archive_handler_audio_program_title_field',
        'option' => array(
           '#type' => 'select',
           '#options' => array(
             'link' => 'As link',
             'nolink' => 'Without link'
           ),
        ),
        'addlfields' => array('program_nid'),
        'help' => t('The program that this audio is a recording of.'),
      ),
    ),
  );

  return $tables;
}

/**
 * Implementation of hook_views_arguments().
 */
function station_archive_views_arguments() {
  $arguments = array(
    'station_archive_program_nid' => array(
      'name' => t('Station Archive: Audio by Program'),
      'handler' => 'station_archive_arg_program_nid_handler',
      'help' => t('The Program NID argument allows visitors to filter archived audio to those of the specified program.'),
    ),
  );
  return $arguments;
}


/**
 * Handle the program node id argument.
 */
function station_archive_arg_program_nid_handler($op, &$query, $argtype, $arg = '') {
  switch($op) {
    case 'summary':
      // add these up front to avoid a wacky bug with rewriting
      $query->ensure_table('node');
      $query->add_field('nid', 'node');
      // now onto our regularly scheduled program
      $query->ensure_table('station_archive_item');
      $query->ensure_table('station_archive_program');
      $query->add_field('title', 'station_archive_program');
      $query->add_field('program_nid', 'station_archive_program');
      $query->add_where('station_archive_program.program_nid IS NOT NULL');
      $fieldinfo['field'] = "station_archive_program.title";
      return $fieldinfo;
    case 'sort':
      $query->ensure_table('station_archive_program');
      $query->add_orderby('station_archive_program', 'title', $argtype);
      break;
    case 'filter':
      $query->ensure_table("station_archive_item");
      $query->add_where("station_archive_item.program_nid = %d", $arg);
      break;
    case 'link':
      return l($query->title, "$arg/" . intval($query->program_nid));
    case 'title':
      $node = db_fetch_object(db_query("SELECT sap.title FROM {station_archive_program} sap WHERE sap.program_nid=%d", $query));
      return check_plain($node->title);
  }
}

function station_archive_handler_timestamp_field($fieldinfo, $fielddata, $value, $data) {
  return l(format_date($value, 'custom', 'j-n-y'), "node/$data->nid");
}

function station_archive_handler_audio_program_title_field($fieldinfo, $fielddata, $value, $data) {
  $schedule = station_default_schedule();
  if ($fielddata['options'] == 'link' && isset($schedule['base_url']) && !empty($data->station_archive_program_program_nid)) {
    return l($value, $schedule['base_url'] .'/node/'. $data->station_archive_program_program_nid);
  }
  return check_plain($value);
}
